package view

import androidx.compose.foundation.gestures.Orientation
import androidx.compose.foundation.gestures.rememberScrollableState
import androidx.compose.foundation.gestures.scrollable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.foundation.lazy.grid.items
import androidx.compose.material3.Button
import androidx.compose.material3.Card
import androidx.compose.material.ExperimentalMaterialApi
import androidx.compose.material3.FilterChip
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.Dialog

@OptIn(ExperimentalMaterialApi::class)
@Composable
fun FilterCard(
    recipeTags: List<String>,
    activeTags: List<String>,
    onDismissRequest : (List<String>) -> Unit,
) {

    val tags by remember { mutableStateOf(recipeTags.sorted()) }
    var tagsFiltered: List<String> = activeTags
    Dialog(
        onDismissRequest = {
            onDismissRequest(activeTags)
        },
    ) {
        Card {
            Box {
                Column {
                    Row {
                        Button(onClick = { onDismissRequest(tagsFiltered) }) {
                            Text("Apply")
                        }
                        Spacer(modifier = Modifier.weight(1f))
                        Button(onClick = { onDismissRequest(listOf()) }) {
                            Text("Clear")
                        }
                    }
                    LazyVerticalGrid(
                        columns = GridCells.Adaptive(minSize = 110.dp)
                    ) {
                        items(tags) { tag ->
                            val active = activeTags.contains(tag)
                            var selected by remember { mutableStateOf(active) }
                            FilterChip(
                                selected = selected,
                                onClick = {
                                    selected = !selected
                                    tagsFiltered = if (selected) {
                                        tagsFiltered.plus(tag)
                                    } else {
                                        tagsFiltered.minus(tag)
                                    }
                                },
                                label = { Text(tag) }
                            )
                        }
                    }
                }
            }
        }
    }
}